
fast-plotter
============


.. image:: https://img.shields.io/pypi/v/fast_plotter.svg
   :target: https://pypi.python.org/pypi/fast_plotter
   :alt: pypi package


.. image:: https://travis-ci.com/FAST-HEP/fast-plotter.svg?branch=master
   :target: https://travis-ci.com/FAST-HEP/fast-plotter
   :alt: pipeline status


.. image:: https://readthedocs.org/projects/fast-plotter/badge/
   :target: https://fast-plotter.readthedocs.io/
   :alt: Documentation Status

.. image:: https://badges.gitter.im/FAST-HEP/community.svg
   :target: https://gitter.im/FAST-HEP/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge
   :alt: Gitter

To install:

.. code-block:: bash

   pip install fast-plotter

Or for development:

.. code-block:: bash

   pip install -e git+https://github.com/FAST-HEP/fast-plotter.git#egg=fast-plotter

(you may need the :code:`--user` flag)

* Free software: Apache Software License 2.0

Features
--------

* Functions to turn binned dataframes in the form produced from `fast-carpenter <https://gitlab.cern.ch/fast-hep/public/fast-carpenter>`_
* A simple command-line tool to produce plots with decent defaults
